@@ -1,6 +1,6 @@
 #' Functional Singular Value Decomposition
 #' 
-#' FSVD for a pair of dense or sparse functional data. 
+#' FSVD for a pair of dense or sparse functional data.
 #' 
 #' @param Ly1 A list of \emph{n} vectors containing the observed values for each individual. Missing values specified by \code{NA}s are supported for dense case (\code{dataType='dense'}).
 #' @param Lt1 A list of \emph{n} vectors containing the observation time points for each individual corresponding to y. Each vector should be sorted in ascending order.
@@ -21,7 +21,7 @@
 #' \item{kernel}{Smoothing kernel choice, common for mu and covariance; "rect", "gauss", "epan", "gausvar", "quar" - default: "gauss"; dense data are assumed noise-less so no smoothing is performed.}
 #' \item{rmDiag}{Logical describing if the routine should remove diagonal raw cov for cross cov estimation (default: FALSE) }
 #' \item{noScores}{Logical describing if the routine should return functional singular scores or not (default: TRUE) }
-#' \item{regulRS}{String describing if the regularisation of the compositie cross-covariance matrix should be done using 'sigma1' or 'rho' (see ?FPCA for details) (default: 'sigma2') }
+#' \item{regulRS}{String describing if the regularisation of the composite cross-covariance matrix should be done using 'sigma1' or 'rho' (see ?FPCA for details) (default: 'sigma2') }
 #' \item{bwRoutine}{String specifying the routine used to find the optimal bandwidth 'grid-search', 'bobyqa', 'l-bfgs-b' (default: 'l-bfgs-b')}
 #' \item{flip}{Logical describing if the routine should flip the sign of the singular components functions or not after the SVD of the cross-covariance matrix. (default: FALSE)}
 #' \item{useGAM}{Indicator to use gam smoothing instead of local-linear smoothing (semi-parametric option) (default: FALSE)}
@@ -33,8 +33,8 @@
 #' \item{bw1}{The selected (or user specified) bandwidth for smoothing the cross-covariance function across the support of sample 1.}
 #' \item{bw2}{The selected (or user specified) bandwidth for smoothing the cross-covariance function across the support of sample 2.}
 #' \item{CrCov}{The smoothed cross-covariance between samples 1 & 2.}
-#' \item{sValues}{A list of length \emph{nsvd}, each entry containing the singuar value estimates for the FSC estimates.}
-#' \item{nsvd}{The number of singular componentes used.}
+#' \item{sValues}{A list of length \emph{nsvd}, each entry containing the singular value estimates for the FSC estimates.}
+#' \item{nsvd}{The number of singular components used.}
 #' \item{canCorr}{The canonical correlations for each dimension.}
 #' \item{FVE}{A percentage indicating the total variance explained by chosen FSCs with corresponding 'FVEthreshold'.}
 #' \item{sFun1}{An nWorkGrid by \emph{K} matrix containing the estimated singular functions for sample 1.}
@@ -44,7 +44,8 @@
 #' \item{sScores1}{A \emph{n} by \emph{K} matrix containing the singular scores for sample 1.}
 #' \item{sScores2}{A \emph{n} by \emph{K} matrix containing the singular scores for sample 2.}
 #' \item{optns}{A list of options used by the SVD and the FPCA's procedures.}
-#' 
+#' @references
+#' \cite{Yang, W., Müller, H.G., Stadtmüller, U. (2011). Functional singular component analysis. J. Royal Statistical Society B73, 303-324.}
 #' @export
 
 FSVD <- function(Ly1, Lt1, Ly2, Lt2, FPCAoptns1 = NULL, FPCAoptns2 = NULL, SVDoptns = list()){
@@ -236,10 +237,12 @@ FSVD <- function(Ly1, Lt1, Ly2, Lt2, FPCAoptns1 = NULL, FPCAoptns2 = NULL, SVDop
       
     } else { # both are dense, utilize GetINscores as it does the same job
       # sFun1/sFun2 are already in obsGrid1/obsGrid2 in dense case
-      sScores1 = GetINScores(ymat = y1mat, t = lt1, optns = FPCAoptns1,
-                             mu = Ymu1, lambda = sValues, phi = sFun1, sigma2 = FPCAObj1$sigma2)$xiEst    
-      sScores2 = GetINScores(ymat = y2mat, t = lt2, optns = FPCAoptns2,
-                             mu = Ymu2, lambda = sValues, phi = sFun2, sigma2 = FPCAObj2$sigma2)$xiEst
+      temp1 = mapply(function(yvec,tvec)
+        GetINScores(yvec, tvec,optns= FPCAoptns1,obsGrid1,mu = Ymu1,lambda =sValues ,phi = sFun1,sigma2 = FPCAObj1$sigma2),ly1,lt1)
+      sScores1 = t(do.call(cbind,temp1[1,]))
+      temp2 = mapply(function(yvec,tvec)
+        GetINScores(yvec, tvec,optns= FPCAoptns2,obsGrid2,mu = Ymu2,lambda =sValues ,phi = sFun2,sigma2 = FPCAObj2$sigma2),ly2,lt2)
+      sScores2 = t(do.call(cbind,temp2[1,]))
     }
     
   } else {
